==> chromium_113.0.5672.63.orig.tar.xz: chromium-113.0.5672.63/ash/wm/overview/overview_constants.h <==
// Copyright 2018 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_WM_OVERVIEW_OVERVIEW_CONSTANTS_H_
#define ASH_WM_OVERVIEW_OVERVIEW_CONSTANTS_H_

#include "ash/ash_export.h"
#include "ash/style/ash_color_provider.h"
#include "ash/wm/window_mini_view.h"
#include "base/time/time.h"

namespace ash {

// The time duration for transformation animations.
constexpr base::TimeDelta kTransition = base::Milliseconds(300);

// The duration for window restore animation when feature Jellyroll is Enabled.
constexpr base::TimeDelta kWindowRestoreDurationCrOSNext =
    base::Milliseconds(350);

// In the conceptual overview table, the window margin is the space reserved
// around the window within the cell. This margin does not overlap so the
// closest distance between adjacent windows will be twice this amount.
constexpr int kWindowMargin = 5;

// Height of an item header.
constexpr int kHeaderHeightDp = WindowMiniView::kHeaderHeightDp;

// Corner radius of the overview item.
constexpr int kOverviewItemCornerRadius =
    WindowMiniView::kWindowMiniViewCornerRadius;

// Windows whose aspect ratio surpass this (width twice as large as height
// or vice versa) will be classified as too wide or too tall and will be
// handled slightly differently in overview mode.
constexpr float kExtremeWindowRatioThreshold = 2.f;

// Inset for the focus ring around the focusable overview items. The ring is 2px
// thick and should have a 2px gap from the view it is associated with. Since
// the thickness is 2px and the stroke is in the middle, we use a -3px inset to
// achieve this.
constexpr int kFocusRingHaloInset = -3;

}  // namespace ash

#endif  // ASH_WM_OVERVIEW_OVERVIEW_CONSTANTS_H_

==> chromium_115.0.5790.98.orig.tar.xz: chromium-115.0.5790.98/ash/wm/overview/overview_constants.h <==
// Copyright 2018 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_WM_OVERVIEW_OVERVIEW_CONSTANTS_H_
#define ASH_WM_OVERVIEW_OVERVIEW_CONSTANTS_H_

#include "ash/ash_export.h"
#include "ash/style/ash_color_provider.h"
#include "ash/wm/window_mini_view.h"
#include "base/time/time.h"

namespace ash {

// The time duration for transformation animations.
constexpr base::TimeDelta kTransition = base::Milliseconds(300);

// The duration for window restore animation when feature Jellyroll is Enabled.
constexpr base::TimeDelta kWindowRestoreDurationCrOSNext =
    base::Milliseconds(350);

// In the conceptual overview table, the space between two adjacent items
// horizontally and vertically.
constexpr int kSpaceBetweenItemsDp = 10;

// The amount we want to enlarge the dragged overview window.
constexpr int kDraggingEnlargeDp = 10;

// Height of an item header.
constexpr int kHeaderHeightDp = WindowMiniView::kHeaderHeightDp;

// Corner radius of the overview item.
constexpr int kOverviewItemCornerRadius =
    WindowMiniView::kWindowMiniViewCornerRadius;

// Windows whose aspect ratio surpass this (width twice as large as height
// or vice versa) will be classified as too wide or too tall and will be
// handled slightly differently in overview mode.
constexpr float kExtremeWindowRatioThreshold = 2.f;

// Inset for the focus ring around the focusable overview items. The ring is 2px
// thick and should have a 2px gap from the view it is associated with. Since
// the thickness is 2px and the stroke is in the middle, we use a -3px inset to
// achieve this.
constexpr int kFocusRingHaloInset = -3;

}  // namespace ash

#endif  // ASH_WM_OVERVIEW_OVERVIEW_CONSTANTS_H_
